/*
 *
 */
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <X11/xpm.h>

struct colour_entry {
	char mask[4];
	unsigned int value;
};

static int mapped_2_16bit_colours=1;	/* FIXME: this is an option */

struct colour_entry colour_map[256];

static int read_one_colour_entry(char *text_entry,struct colour_entry *col)
{
	col->mask[0]=col->mask[1]=col->mask[2]=col->mask[3]='\0';
	return sscanf(text_entry,"%2c c #%x",&col->mask[0],&col->value);
}

/* map RGB 8:8:8 to 5:6:5 */
static unsigned int map_colour_entry(unsigned int rgb_colour)
{
	unsigned int pixel;

	pixel  = (rgb_colour >> 3) & 0x001F;	/* blue 5 bit */
	pixel |= (rgb_colour >> 5) & 0x07E0;	/* green 6 bit */
	pixel |= (rgb_colour >> 8) & 0xF800;	/* red 5 bit */

	return pixel;
}

static unsigned int find_colour_entry(char *text,size_t size,
				int entries,struct colour_entry *col_map)
{
	unsigned int i;

	for (i=0;i<entries;i++) {
		if (!strncmp(col_map[i].mask,text,size))
			return i;
	}
	return -1;
}

static int print_sourcefile(unsigned char *bitmap,int width,int height,struct colour_entry *colour_map,int colours)
{
	int i,j,size=width*height;

	printf("/* do not edit\nThis is an image of size %d x %d with %d colours */\n",width,height,colours);
	printf("static const int width=%d;\nstatic const int height=%d;\nstatic const int colours=%d;\n",
		width,height,colours);
	printf("static const unsigned long colour_map[%d] = {\n",colours);

	for (i=0;i<colours;i++)
		printf("0x%08X, /* %d */\n",colour_map[i].value,i);

	printf("};\n\nstatic const unsigned char bitmap[%d] = {\n",size);
	j=0;
	do {
		for (i=0;i<width;i++,size--) {
			printf("0x%02X,",bitmap[j++]);
			if (size==0)
				break;
		}
		printf("\n");
	}
	while(size != 0);
	printf("};\n");

	return 0;
}


int main(int argc,char *argv[])
{
	char **data;
	int i,max_row,index,collumn;
	int width, height,colours,depth;
	char *bitmap,*textp;

	XpmReadFileToData(argv[1],&data);

	sscanf(data[0],"%d %d %d %d",&width,&height,&colours,&depth);
/*	printf ("This pixmap is %d by %d with %d colours\n",width, height,colours); */

	for (i=0;i<colours;i++)
		read_one_colour_entry(data[1+i],&colour_map[i]);

	if (mapped_2_16bit_colours != 0) {
		for (i=0;i<colours;i++)
			colour_map[i].value=map_colour_entry(colour_map[i].value);
	}

	bitmap=calloc(width*height,sizeof(*bitmap));
/*	for (i=0;i<colours;i++)
		printf("Mask is %s, Colour is %08X\n",colour_map[i].mask,colour_map[i].value); */

	max_row=height+colours;
	index=0;
	i=colours+1;
	while(i<=max_row) {
		for (collumn=0,textp=data[i];collumn < width;collumn++,textp+=depth) {
			bitmap[index++]=find_colour_entry(textp,depth,colours,colour_map);
		}
		i++;
	}

	print_sourcefile((unsigned char*)bitmap,width,height,colour_map,colours);
	free(bitmap);
	XpmFree(data);
	return 0;
}

/* */
